@@ -6,7 +6,8 @@ use Class::Tiny qw(fetcher);
 use File::Basename ();
 use File::Spec ();
 use URI ();
-use IO::Uncompress::Gunzip ();
+
+our $HAS_IO_UNCOMPRESS_GUNZIP = eval { require IO::Uncompress::Gunzip };
 
 my %INDICES = (
 #    mailrc   => 'authors/01mailrc.txt.gz',
@@ -17,12 +18,16 @@ sub refresh_index {
     my $self = shift;
     for my $file ( values %INDICES ) {
         my $remote = URI->new_abs( $file, $self->mirror );
+        $remote =~ s/\.gz$//
+          unless $HAS_IO_UNCOMPRESS_GUNZIP;
         my $local = File::Spec->catfile( $self->cache, File::Basename::basename($file) );
         $self->fetcher->($remote, $local)
           or Carp::croak( "Cannot fetch $remote to $local");
-        ( my $uncompressed = $local ) =~ s/\.gz$//;
-        IO::Uncompress::Gunzip::gunzip( $local, $uncompressed )
-          or Carp::croak "gunzip failed: $IO::Uncompress::Gunzip::GunzipError\n";
+        if ($HAS_IO_UNCOMPRESS_GUNZIP) {
+            ( my $uncompressed = $local ) =~ s/\.gz$//;
+            IO::Uncompress::Gunzip::gunzip( $local, $uncompressed )
+              or Carp::croak "gunzip failed: $IO::Uncompress::Gunzip::GunzipError\n";
+        }
     }
 }
 
